---
title: 'Data Source to Dashboard'
---

## Data Lifecycle

### How we currently structure Meltano

| Stage       | Meltano selected                                                                     | OSS considered but not selected                                                                                                          | Proprietary alternatives                                                                                                                                       |
| ----------- | ------------------------------------------------------------------------------------ | ---------------------------------------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| Model       | [Meltano Model](https://gitlab.com/meltano/meltano#meltano-model)                    | [Open ModelSphere](http://www.modelsphere.com/org/)                                                                                      | [LookML](https://looker.com/platform/data-modeling), [Matillion](http://www.stephenlevin.co/data-modeling-layer-startup-analytics-dbt-vs-matillion-vs-lookml/) |
| Extract     | [Singer Tap](https://gitlab.com/meltano/meltano#tap)                                 | [Pentaho DI](http://www.pentaho.com/product/data-integration), [Talend](https://www.talend.com/)                                         | [Alooma](https://www.alooma.com/), [Fivetran](https://fivetran.com/)                                                                                           |
| Load        | [Singer Target](https://gitlab.com/meltano/meltano#target)                           | [Pentaho DI](http://www.pentaho.com/product/data-integration), [Talend](https://www.talend.com/)                                         | [Alooma](https://www.alooma.com/), [Fivetran](https://fivetran.com/)                                                                                           |
| Transform   | [dbt](https://www.getdbt.com/)                                                       | [Stored procedures](https://gitlab.com/meltano/meltano#stored-procedures), [Pentaho DI](http://www.pentaho.com/product/data-integration) | [Alooma](https://www.alooma.com/)                                                                                                                              |
| Analyze     | [Meltano Analyze](https://gitlab.com/meltano/meltano/tree/master/src/analyze)        | [Metabase](https://www.metabase.com/)                                                                                                    | [Looker](https://looker.com/), [Periscope](https://www.periscopedata.com/)                                                                                     |
| Notebook    | [JupyterHub](https://github.com/jupyterhub/jupyterhub)                               | [GNU Octave](https://www.gnu.org/software/octave/)                                                                                       | [Nurtch](https://www.nurtch.com/), [Datadog notebooks](https://www.datadoghq.com/blog/data-driven-notebooks/)                                                  |
| Orchestrate | [GitLab CI](https://docs.gitlab.com/ee/ci/) / [Airflow](https://airflow.apache.org/) | [Luigi](https://github.com/spotify/luigi), [Nifi](https://nifi.apache.org/)                                                              | [Fivetran](https://fivetran.com/)                                                                                                                              |
